=======================================
otoole : OSeMOSYS tools for energy work
=======================================

.. image:: https://travis-ci.com/OSeMOSYS/otoole.svg?branch=master
    :target: https://travis-ci.com/OSeMOSYS/otoole

.. image:: https://coveralls.io/repos/github/OSeMOSYS/otoole/badge.svg?branch=master
    :target: https://coveralls.io/github/OSeMOSYS/otoole?branch=master

.. image:: https://readthedocs.org/projects/otoole/badge/?version=latest
    :target: https://otoole.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

A Python toolkit to support use of OSeMOSYS


Description
===========

**otoole** is a Python package which provides a command-line interface
for users of OSeMOSYS.

The aim of the package is to provide a community resource which
centralises the commonly used pre- and post-processing steps
around the use of OSeMOSYS.

Installation
============

Install **otoole** using pip::

    pip install otoole


Note
====

This project has been set up using PyScaffold 3.2.2. For details and usage
information on PyScaffold see https://pyscaffold.org/.
